.. _index:

=========
Croud CLI
=========

*Croud* is a *command-line interface* (CLI) tool for interacting with `CrateDB
Cloud`_.

.. rubric:: Table of Contents

.. contents::
   :local:

.. toctree::
   :maxdepth: 2

   getting-started
   commands/index
   user-roles

.. _CrateDB Cloud: https://crate.io/products/cratedb-cloud/
